=============
pywe-response
=============

Wechat Server Response Module for Python.

Installation
============

::

    pip install pywe-response


Usage
=====

::

    from pywe_response import WXPAY_NOTIFY_SUCCESS, WXPAY_NOTIFY_FAIL

